@@ -7,6 +7,6 @@ from django.conf import settings
 if not settings.configured:
     settings.configure()
 
-SERVER_URI = getattr(settings, 'SERVER_URI', "http://localhost")
+SERVER_URI = getattr(settings, "SERVER_URI", "http://localhost")
 
-INSTALLED_APPS = getattr(settings, 'INSTALLED_APPS', [])
+INSTALLED_APPS = getattr(settings, "INSTALLED_APPS", [])
